import java.util.ArrayList;
public class Polynomial extends ArrayList<Double> {
    private static final long serialVersionUID = 1692843494322684190L;

	/**
	 * @param degree
	 *            The degree of the polynomial
	 */
    public Polynomial(final int degree) {
        super(degree);
    }

    /**
     * Returns the value of the polynomial at the point x
     * 
     * @param x Point at which the polynomial is calculated
     * @return Value of the polynomial
     */
    public double getY(final double x) {
        double ret = 0;
        for (int p=0; p<size(); p++) {
            ret += get(p)*(Math.pow(x, p));
        }
        return ret;
    }

    /**
     * Returns the value of the nth coefficient of the polynomial
     * 
     * @param n order of the coefficient
     * @return value of the nth coefficient
     */
    public double coef(int n) {
        return get(n);
    }

    /**
     * Returns the polynomial as a String
     * 
     * @return polynomial as a String
     */
    @Override
    public String toString() {
        final StringBuilder ret = new StringBuilder();
        for (int x = size() - 1; x > -1; x--) {
            ret.append(get(x) + (x > 0 ? "x^" + x + " + " : ""));
        }
        return ret.toString();
    }
}